@@ -40,7 +40,7 @@ class BayesBridge():
 
     # TODO: write a test to ensure that the output when resuming the Gibbs
     # sampler coincide with that without interruption.
-    def gibbs_additional_iter(
+    def gibbs_resume(
             self, prev_mcmc_info, n_add_iter, n_status_update=0,
             merge=False, prev_samples=None):
         """ Resume Gibbs sampler from the last state.
@@ -49,18 +49,24 @@ class BayesBridge():
         ---------
         prev_mcmc_info : dict
             MCMC info returned by a previous call to the `gibbs` method.
-        n_iter : int
+        n_add_iter : int
+            Number of additional iterations.
         n_status_update : int
+            Number of updates to print on stdout during the sampler run.
         merge : bool
             If True, merge the Gibbs sampler outputs from the previous and
-            new runs and then return.
+            new runs, so that the return values coincide with one combined run
+            of `gibbs` with the `n_burnin` burn-in and `n_iter + n_add_iter`
+            post-burnin iterations.
         prev_samples : dict
             MCMC samples returned by a previous call to the 'gibbs' method.
 
         Returns
         -------
         new_samples : dict
+          See the documentation for `gibbs()`.
         new_mcmc_info : dict
+          See the documentation for `gibbs()`.
         """
 
         if merge and prev_samples is None:
@@ -283,7 +289,7 @@ class BayesBridge():
         coef_only_specified = 'coef' in init and ('global_scale' not in init)
 
         if 'coef' in init:
-            coef = init['coef']
+            coef = init['coef'].copy()
             if not len(coef) == self.n_pred:
                 raise ValueError('Invalid initial length of regression coefficient.')
         else:
@@ -310,11 +316,11 @@ class BayesBridge():
                      "the specified initial value is scaled accordingly.")
             gscale = init['global_scale']
             if 'local_scale' in init:
-                lscale = init['local_scale']
+                lscale = init['local_scale'].copy()
                 if not len(lscale) == (self.n_pred - self.n_unshrunk):
                     raise ValueError('Invalid initial length of local scale parameter')
             else:
-                lscale = np.ones(self.n_pred - self.n_unshrunk) / gscale
+                lscale = np.ones(self.n_pred - self.n_unshrunk)
 
         if self.prior._gscale_paramet == 'coef_magnitude':
             # Gibbs sampler requires the raw parametrization, though
@@ -348,7 +354,7 @@ class BayesBridge():
 
     def initialize_obs_precision(self, init, coef):
         if 'obs_prec' in init:
-            obs_prec = np.ascontiguousarray(init['obs_prec'])
+            obs_prec = init['obs_prec'].copy(order='C')
             # Cython requires a C-contiguous array.
             if not len(obs_prec) == self.n_obs:
                 raise ValueError('An invalid initial state.')
@@ -451,6 +457,9 @@ class BayesBridge():
 
     def update_local_scale(self, gscale, beta_with_shrinkage, bridge_exp):
 
+        if bridge_exp == 2:
+            return np.ones(beta_with_shrinkage.size)
+
         lscale_sq = .5 / self.rg.tilted_stable(
             bridge_exp / 2, (beta_with_shrinkage / gscale) ** 2
         )
